==> spirit_hub-0.1.1.22.tar.gz: spirit_hub-0.1.1.22/app/overrides/doc.rb <==
# frozen_string_literal: true

Doc.prepend(Turbo::Broadcastable)
Doc.class_eval do
  after_save :update_tagset_doc_doc_fields, :generate_preview_turbo_stream

  def pdf?
    file_ext == 'pdf'
  end

  def self.create_from_file!(file, user)
    doc = Doc.create!(responsible: user&.id, title: file.original_filename)
    doc.blob = file.read
    doc.update!(type: 'file')
    doc.logs.create(user_id: user.id, action: 'Création du fichier', code: 'CFB') if user
    doc
  end

  def update_tagset_doc_doc_fields
    return unless %i[file_ext doc_file_size tagset_id].any? { |attr| saved_change_to_attribute?(attr) }

    Tagset.where(type: 'document', doc_ids: id).each do |tagset|
      tagset.update_docs_fields
      tagset.save if tagset.changed?
    end
  end

  def doc_download_url
    "/documents/#{id}/upload?mode=attachment"
  end

  private

  def generate_preview_turbo_stream
    attribute_to_check = pdf? ? :file_md5 : :pages_urls
    return unless saved_change_to_attribute?(attribute_to_check)

    broadcast_append_to "doc_viewer_#{id}",
                        target: 'flash_messages',
                        partial: 'spirit_hub/common/flash_messages',
                        locals: { flash: { notice: 'Le document a été mis à jour' } }

    broadcast_replace_to("doc_viewer_#{id}",
                         target: "doc_viewer_#{id}",
                         partial: 'spirit_hub/common/doc_viewer_content',
                         locals: { doc: self, doc_download_url: })
  end

  def suppressed_turbo_broadcasts?
    false
  end
end

==> spirit_hub-0.1.1.25.tar.gz: spirit_hub-0.1.1.25/app/overrides/doc.rb <==
# frozen_string_literal: true

Doc.prepend(Turbo::Broadcastable)
Doc.class_eval do
  after_save :update_tagset_doc_doc_fields, :generate_preview_turbo_stream

  def pdf?
    file_ext == 'pdf'
  end

  def self.create_from_file!(file, user)
    if file.is_a?(ActionDispatch::Http::UploadedFile)
      create_from_open_file(file, user)
    else
      File.open(file) { |f| create_from_open_file(f, user) }
    end
  end

  def self.create_from_open_file(file, user)
    file_name = file.respond_to?(:original_filename) ? file.original_filename : File.basename(file)
    doc = Doc.create!(responsible: user&.id, title: file_name)
    doc.blob = file.read
    doc.update!(type: 'file')
    doc.logs.create(user_id: user.id, action: 'Création du fichier', code: 'CFB') if user
    doc
  end

  def update_tagset_doc_doc_fields
    return unless %i[file_ext doc_file_size tagset_id].any? { |attr| saved_change_to_attribute?(attr) }

    Tagset.where(type: 'document', doc_ids: id).each do |tagset|
      tagset.update_docs_fields
      tagset.save if tagset.changed?
    end
  end

  def doc_download_url
    "/documents/#{id}/upload?mode=attachment"
  end

  private

  def generate_preview_turbo_stream
    attribute_to_check = pdf? ? :file_md5 : :pages_urls
    return unless saved_change_to_attribute?(attribute_to_check)

    broadcast_append_to("doc_viewer_#{id}",
                        target: 'flash_messages',
                        renderable: FlashMessagesComponent.new(flash: { notice: 'Le document a été mis à jour' }))

    broadcast_replace_to("doc_viewer_#{id}",
                         target: "doc_viewer_#{id}",
                         partial: 'spirit_hub/common/doc_viewer_content',
                         locals: { doc: self, doc_download_url: })
  end

  def suppressed_turbo_broadcasts?
    false
  end
end
